==> domain_language_google_tag-8.x-1.0.tar.gz: domain_language_google_tag/src/EventSubscriber/GoogleTagResponseSubscriber.php <==
<?php

namespace Drupal\domain_language_google_tag\EventSubscriber;

use Drupal\Core\Config\ConfigFactoryInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\Event\FilterResponseEvent;
use Symfony\Component\HttpKernel\KernelEvents;
use Drupal\domain\DomainNegotiatorInterface;
use Drupal\Core\Language\LanguageManager;

/**
 * Class GoogleAnalyticResponseSubscriber.
 *
 * @package Drupal\domain_language_google_tag\EventSubscriber
 */
class GoogleTagResponseSubscriber implements EventSubscriberInterface {

  /**
   * The config object for the domain_language_google_tag settings.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * The DomainNegotiator.
   *
   * @var \Drupal\domain\DomainNegotiatorInterface
   */
  protected $activeDomain;

  /**
   * The LanguageManager.
   *
   * @var \Drupal\Core\Language\LanguageManager
   */
  protected $languageManager;

  /**
   * Constructs a new Google Analytics response subscriber.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory service.
   * @param \Drupal\domain\DomainNegotiatorInterface $negotiator
   *   The domain negotiator service.
   * @param \Drupal\Core\Language\LanguageManager $languageManager
   *   The language manager service.
   */
  public function __construct(ConfigFactoryInterface $configFactory, DomainNegotiatorInterface $negotiator, LanguageManager $languageManager) {
    $this->config = $configFactory->get('domain_language_google_tag_settings.settings');
    $this->languageManager = $languageManager;
    if ($negotiator->getActiveDomain()) {
      $this->activeDomain = $negotiator->getActiveId();
    }
  }

  /**
   * Add a tags in boby.
   *
   * @param \Symfony\Component\HttpKernel\Event\FilterResponseEvent $event
   *
   *   Set response.
   */
  public function addTag(FilterResponseEvent $event) {
    if (!$event->isMasterRequest()) {
      return;
    }

    $currentLanguage = $this->languageManager->getCurrentLanguage()->getId();

    $response = $event->getResponse();
    $compact = '';
    if ($this->activeDomain) {
      $compact = $this->config->get($this->activeDomain . '_' . $currentLanguage);

      if (is_null($compact) || empty($compact)) {
        $compact = $this->config->get($this->activeDomain . '_global');

        if (is_null($compact) || empty($compact)) {
          $compact = $this->config->get('global_id');
        }
      }
    }

    // Insert snippet after the opening head tag.
    if ($compact) {
      $response_text = preg_replace('@<head[^>]*>@', '$0' . $this->getTagHead($compact), $response->getContent(), 1);
      $response->setContent($response_text);
    }

    // Insert snippet after the opening body tag.
    if ($compact) {
      $response_text = preg_replace('@<body[^>]*>@', '$0' . $this->getTagHead($compact), $response->getContent(), 1);
      $response->setContent($response_text);
    }
  }

  /**
   * Return the text for the tag.
   *
   * @param bool $compact
   *   Whether or not the tag should be compacted (whitespace removed).
   *
   * @return string
   *   The full text of the Google Analytic script/embed.
   */
  public function getTagHead($compact = FALSE) {
    // Build script tags.
    $script = [];
    $script = <<<EOS
      <script>(function(w,d,s,l,i){w[l]=w[l]||[];w[l].push({'gtm.start':
      new Date().getTime(),event:'gtm.js'});var f=d.getElementsByTagName(s)[0],
      j=d.createElement(s),dl=l!='dataLayer'?'&l='+l:'';j.async=true;j.src=
      'https://www.googletagmanager.com/gtm.js?id='+i+dl;f.parentNode.insertBefore(j,f);
      })(window,document,'script','dataLayer','$compact');</script>
EOS;

    if ($compact) {
      $script = str_replace(["\n", '  '], '', $script);
    }
    $script = <<<EOS
    <!-- Google Tag Manager -->
    $script
    <!-- End Tag Manager -->
EOS;

    return $script;
  }

  /**
   * Return the text for the tag.
   *
   * @param bool $compact
   *   Whether or not the tag should be compacted (whitespace removed).
   *
   * @return string
   *   The full text of the Google Analytic script/embed.
   */
  public function getTagBody($compact = FALSE) {
    // Build script tags.
    $script = [];
    $script = <<<EOS
      <!-- Google Tag Manager (noscript) -->
      <noscript><iframe src="https://www.googletagmanager.com/ns.html?id=$compact"
      height="0" width="0" style="display:none;visibility:hidden"></iframe></noscript>
      <!-- End Google Tag Manager (noscript) -->
EOS;

    if ($compact) {
      $script = str_replace(["\n", '  '], '', $script);
    }
    $script = <<<EOS
    <!-- Google Tag Manager (noscript) -->
    $script
    <!-- End Tag Manager (noscript) -->
EOS;

    return $script;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[KernelEvents::RESPONSE][] = ['addTag', -500];
    return $events;
  }

}

==> domain_language_google_tag-8.x-1.2.tar.gz: domain_language_google_tag/src/EventSubscriber/GoogleTagResponseSubscriber.php <==
<?php

namespace Drupal\domain_language_google_tag\EventSubscriber;

use Drupal\Core\Config\ConfigFactoryInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\Event\FilterResponseEvent;
use Symfony\Component\HttpKernel\KernelEvents;
use Drupal\domain\DomainNegotiatorInterface;
use Drupal\Core\Language\LanguageManager;

/**
 * Class GoogleTagResponseSubscriber.
 *
 * @package Drupal\domain_language_google_tag\EventSubscriber
 */
class GoogleTagResponseSubscriber implements EventSubscriberInterface {

  /**
   * The config object for the domain_language_google_tag settings.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * The DomainNegotiator.
   *
   * @var \Drupal\domain\DomainNegotiatorInterface
   */
  protected $activeDomain;

  /**
   * The LanguageManager.
   *
   * @var \Drupal\Core\Language\LanguageManager
   */
  protected $languageManager;

  /**
   * Constructs a new Google Tag Manager response subscriber.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory service.
   * @param \Drupal\domain\DomainNegotiatorInterface $negotiator
   *   The domain negotiator service.
   * @param \Drupal\Core\Language\LanguageManager $languageManager
   *   The language manager service.
   */
  public function __construct(ConfigFactoryInterface $configFactory, DomainNegotiatorInterface $negotiator, LanguageManager $languageManager) {
    $this->config = $configFactory->get('domain_language_google_tag_settings.settings');
    $this->languageManager = $languageManager;
    if ($negotiator->getActiveDomain()) {
      $this->activeDomain = $negotiator->getActiveId();
    }
  }

  /**
   * Add a tags in boby.
   *
   * @param \Symfony\Component\HttpKernel\Event\FilterResponseEvent $event
   *
   *   Set response.
   */
  public function addTag(FilterResponseEvent $event) {
    if (!$event->isMasterRequest()) {
      return;
    }

    $currentLanguage = $this->languageManager->getCurrentLanguage()->getId();

    $response = $event->getResponse();
    $compact = '';
    if ($this->activeDomain) {
      $compact = $this->config->get($this->activeDomain . '_' . $currentLanguage);

      if (is_null($compact) || empty($compact)) {
        $compact = $this->config->get($this->activeDomain . '_global');

        if (is_null($compact) || empty($compact)) {
          $compact = $this->config->get('global_id');
        }
      }
    }

    // Insert snippet after the opening head tag.
    if ($compact) {
      $response_text = preg_replace('@<head[^>]*>@', '$0' . $this->getTagHead($compact), $response->getContent(), 1);
      $response->setContent($response_text);
    }

    // Insert snippet after the opening body tag.
    if ($compact) {
      $response_text = preg_replace('@<body[^>]*>@', '$0' . $this->getTagHead($compact), $response->getContent(), 1);
      $response->setContent($response_text);
    }
  }

  /**
   * Return the text for the tag.
   *
   * @param bool $compact
   *   Whether or not the tag should be compacted (whitespace removed).
   *
   * @return string
   *   The full text of the Google Tag Manager script/embed.
   */
  public function getTagHead($compact = FALSE) {
    // Build script tags.
    $script = [];
    $script = <<<EOS
      <script>(function(w,d,s,l,i){w[l]=w[l]||[];w[l].push({'gtm.start':
      new Date().getTime(),event:'gtm.js'});var f=d.getElementsByTagName(s)[0],
      j=d.createElement(s),dl=l!='dataLayer'?'&l='+l:'';j.async=true;j.src=
      'https://www.googletagmanager.com/gtm.js?id='+i+dl;f.parentNode.insertBefore(j,f);
      })(window,document,'script','dataLayer','$compact');</script>
EOS;

    if ($compact) {
      $script = str_replace(["\n", '  '], '', $script);
    }
    $script = <<<EOS
    <!-- Google Tag Manager -->
    $script
    <!-- End Tag Manager -->
EOS;

    return $script;
  }

  /**
   * Return the text for the tag.
   *
   * @param bool $compact
   *   Whether or not the tag should be compacted (whitespace removed).
   *
   * @return string
   *   The full text of the Google Tag Manager script/embed.
   */
  public function getTagBody($compact = FALSE) {
    // Build script tags.
    $script = [];
    $script = <<<EOS
      <!-- Google Tag Manager (noscript) -->
      <noscript><iframe src="https://www.googletagmanager.com/ns.html?id=$compact"
      height="0" width="0" style="display:none;visibility:hidden"></iframe></noscript>
      <!-- End Google Tag Manager (noscript) -->
EOS;

    if ($compact) {
      $script = str_replace(["\n", '  '], '', $script);
    }
    $script = <<<EOS
    <!-- Google Tag Manager (noscript) -->
    $script
    <!-- End Tag Manager (noscript) -->
EOS;

    return $script;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[KernelEvents::RESPONSE][] = ['addTag', -500];
    return $events;
  }

}
